@@ -1,5 +1,3 @@
-
-
 #' @importFrom graphics axis barplot mtext plot polygon title
 #' @examples
 #' 
@@ -21,4 +19,8 @@
 #' 
 "_PACKAGE"
 
-
+# The following block is used by usethis to automatically manage
+# roxygen namespace tags. Modify with care!
+## usethis namespace: start
+## usethis namespace: end
+NULL
